Package {GenerateIndexPedigree}


Type: Package
Title: Generate Pedigrees for Index Case Based on US Census Data
Version: 1.0.0
Maintainer: Katelyn Queen <kqueen@mednet.ucla.edu>
Description: A series of functions to generate a pedigree around a given person with a known genetic mutation, based on US census data. Pedigree will also track mutation status of all members. Pedigree is built down to children, back to grandparents, and out to cousins. There is also a function to generate pedigrees without genetic mutations.
License: MIT + file LICENSE
URL: https://github.com/katelynqueen98/GenerateIndexPedigree
Imports: dplyr, stats
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-06-08 18:17:04 UTC; kqueen
Author: Katelyn Queen ORCID iD [aut, cre, cph], Kevin Abuhanna ORCID iD [aut], Paul Spellman ORCID iD [aut, cph]
Repository: CRAN
Date/Publication: 2026-06-16 19:50:13 UTC

GenerateIndexPedigree

Description

Function to simulate pedigree of index case to first cousins and back to grandparents; Genetic mutation of index is permeated through pedigree, and if the family members are told about mutation and if they uptake genetic testing is tracked

Usage

GenerateIndexPedigree(
  age,
  sex,
  keep_future_children = TRUE,
  variant = "None",
  denovo_rate = 2e-06,
  is_denovo = NA,
  tell_family_prob = 0.7,
  tell_children_prob = 0.8,
  uptake_test_prob = 0.45,
  verbose = FALSE
)

Arguments

age

numeric, age of index case

sex

character, index case sex; either "M" or "F"

keep_future_children

logical, whether to keep (TRUE) or remove (FALSE) children not yet born; default is TRUE

variant

character, name of variant; default is "None" for unaffected index

denovo_rate

numeric, between 0 and 1; rate of denovo mutation in given variant; default is 1/500000 or 2x10^(-6)

is_denovo

logical, index mutation is de novo (TRUE) or inherited (FALSE); NA indicates denovo status is unknown and will be simulated; default is NA

tell_family_prob

numeric, between 0 and 1; probability that an index case tells their family about their mutation; default is 0.70

tell_children_prob

numeric, between 0 and 1; probability that an index case tells their children about their mutation, assumed this is <= tell_family_prob; default is 0.80

uptake_test_prob

numeric, between 0 and 1; probability that a family member who is told about index mutation will get a genetic test; default is 0.45

verbose

logical, whether to print messages during function; default is FALSE

Details

This function simulates pedigrees of individuals with a genetic mutation of interest, tracking family structure, variant permeation, and uptake of genetic testing. Family sizes are based on appropriate US census data, and due to correlation between number of children within pedigrees, this starts with assigning overall pedigree size to small, average, or large.

Children for each adult are generated using the SimulateChildren function.

Value

a data frame representing the family, where each row represents a person and columns represent attributes:

Age

numeric, person age

Sex

character, person sex; either "M" or "F"

RelationshipToIndex

character, person's relationship to index

ChildOf

character, which family member person is child of; NA for grandparents

DeNovo

logical, NA/True whether mutation is de novo; only possible to be true for index and parent

Variant

character, person's variant status; either NA or same as parameter

Told

character, Yes/No, whether person was informed of index case

UptakeTesting

character, Yes/No, on whether person chose to receive genetic health screening

Author(s)

Katelyn Queen kqueen@mednet.ucla.edu

References

Schweizer and Guzzo. Distributions of Age at First Birth, 1960-2018 (2020); https://www.bgsu.edu/ncfmr/resources/data/family-profiles/schweizer-guzzo-distribution-age-first-birth-fp-20-11.html

Khandwala, Zhang, Lu, and Eisenberg. The age of fathers in the USA is rising: an analysis of 168 867 480 births from 1972 to 2015, Human Reproduction, Volume 32, Issue 10, October 2017, Pages 2110–2116, https://doi.org/10.1093/humrep/dex267

Examples

GenerateIndexPedigree(age = 35, variant = "BRCA1", sex = "M", is_denovo = NA)


GeneratePedigree

Description

Function to simulate pedigree of given individual to first cousins and back to grandparents

Usage

GeneratePedigree(age, sex, keep_future_children = TRUE)

Arguments

age

numeric, age of index case

sex

character, patient sex; either "M" or "F"

keep_future_children

logical, whether to keep (TRUE) or remove (FALSE) children not yet born; default is TRUE

Details

This function simulates pedigrees of individuals given age and sex. Family sizes are based on appropriate US census data, and due to correlation between number of children within pedigrees, this starts with assigning overall pedigree size to small, average, or large.

Children for each adult are generated using the SimulateChildren function.

Value

a data frame representing the family, where each row represents a person and columns represent attributes:

Age

numeric, person age

Sex

character, person sex; either "M" or "F"

RelationshipToIndex

character, person's relationship to index

ChildOf

character, which family member person is child of; NA for grandparents

Author(s)

Katelyn Queen kqueen@mednet.ucla.edu

References

Schweizer and Guzzo. Distributions of Age at First Birth, 1960-2018 (2020); https://www.bgsu.edu/ncfmr/resources/data/family-profiles/schweizer-guzzo-distribution-age-first-birth-fp-20-11.html

Khandwala, Zhang, Lu, and Eisenberg. The age of fathers in the USA is rising: an analysis of 168 867 480 births from 1972 to 2015, Human Reproduction, Volume 32, Issue 10, October 2017, Pages 2110–2116, https://doi.org/10.1093/humrep/dex267

Examples

GeneratePedigree(age = 35, sex = "M")


SimulateChildren

Description

Function to simulate number and ages of children given age of mother or father

Usage

SimulateChildren(
  mother_age,
  father_age = NA,
  pedigree_size = "Average",
  variant = "None",
  has_children = FALSE,
  known_child_age = NA,
  current_year = 2026
)

Arguments

mother_age

numeric, age of mother

father_age

numeric, age of father, if known; only required if simulating children based on father; default is NA

pedigree_size

character, one of "Small", "Average", or "Large"; indicates average size of family in pedigree; default is "Average"

variant

character, name of variant for index case; default is "None" for unaffected index

has_children

logical, represents whether is known if parent has children; default is FALSE

known_child_age

numeric, age of known child; only used if has_children is TRUE

current_year

numeric, year to age individuals to; default is 2026

Details

This function generates children given parental ages, pedigree size, variant status, and current year has_children and known_child_age are for generating past generations where we know there is at least one child of age X. If father_age given, calls .GenerateChildrenFromFather

Value

a dataframe representing the children of indicated parent, where each row represents a person and columns represent attributes:

Age

numeric, person age

Sex

character, person sex; either "M" or "F"

Variant

character, person's variant status; either NA or same as parameter

Father

character, denotes which father child came from; accounts for complex family structures

Author(s)

Katelyn Queen kqueen@mednet.ucla.edu

References

Guzzo KB. New Partners, More Kids: Multiple-Partner Fertility in the United States. Ann Am Acad Pol Soc Sci. 2014 Jul;654(1):66-86. doi: 10.1177/0002716214525571.

Monte and Knop, United States Census Bureau. Men's Fertility and Fatherhood: 2014 (2019); https://www.census.gov/content/dam/Census/library/publications/2019/demo/P70-162.pdf

Pew Research Center. The Modern American Family (2023); https://www.pewresearch.org/social-trends/2023/09/14/the-modern-american-family/

Schwartz, Doren, and Li, The Springer Series on Demographic Methods and Population Analysis, vol 51 (2020), DOI: 10.1007/978-3-030-48519-1_10

Schweizer. 30 Years of Change in Men's Entry into Fatherhood, 1987-2017 (2019); https://www.bgsu.edu/ncfmr/resources/data/family-profiles/schweizer-years-change-mens-entry-fatherhood-fp-19-28.html

Schweizer and Guzzo. Distributions of Age at First Birth, 1960-2018 (2020); https://www.bgsu.edu/ncfmr/resources/data/family-profiles/schweizer-guzzo-distribution-age-first-birth-fp-20-11.html

United States Census Bureau. Annual Social and Economic Supplements; https://www.census.gov/data/datasets/time-series/demo/cps/cps-asec.html

Examples

SimulateChildren(mother_age = 35, pedigree_size = "Small", variant = "BRCA1")